@@ -18,49 +18,64 @@
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
 from pygal.graph.graph import Graph
 from math import cos, sin, pi
+project = lambda rho, alpha: (
+    rho * sin(-alpha), rho * cos(-alpha))
+diff = lambda x, y: (x[0] - y[0], x[1] - y[1])
+fmt = lambda x: '%f %f' % x
+get_radius = lambda r: fmt(tuple([r] * 2))
 
 
 class Pie(Graph):
     """Pie graph"""
 
-    def slice(self, serie_node, start_angle, angle, perc, tag,
+    def slice(self, serie_node, start_angle, angle, perc,
             small=False):
+        val = '{:.2%}'.format(perc)
         slices = self.svg.node(serie_node['plot'], class_="slices")
         slice_ = self.svg.node(slices, class_="slice")
         center = ((self.width - self.margin.x) / 2.,
                   (self.height - self.margin.y) / 2.)
         r = min(center)
         if small:
-            r *= .9
-        center_str = '%f %f' % center
+            small_r = r * .9
+        else:
+            r = r * .9
+            small_r = 0
         if perc == 1:
             self.svg.node(slice_, 'circle',
                           cx=center[0],
                           cy=center[1],
                           r=r,
-                          id="active-%s" % tag,
-                          class_='slice reactive')
+                          class_='slice reactive tooltip-trigger')
         else:
-            rxy = '%f %f' % tuple([r] * 2)
-            to = '%f %f' % (r * sin(angle), r * (1 - cos(angle)))
+            absolute_project = lambda rho, theta: fmt(
+                diff(center, project(rho, theta)))
+            to1 = absolute_project(r, start_angle)
+            to2 = absolute_project(r, start_angle + angle)
+            to3 = absolute_project(small_r, start_angle + angle)
+            to4 = absolute_project(small_r, start_angle)
             self.svg.node(slice_, 'path',
-                          d='M%s v%f a%s 0 %d 1 %s z' % (
-                              center_str, -r,
-                              rxy,
-                              1 if angle > pi else 0,
-                              to),
-                          id="active-%s" % tag,
-                          transform='rotate(%f %s)' % (
-                              start_angle * 180 / pi, center_str),
-                          class_='slice reactive')
-        text_angle = pi / 2. - (start_angle + angle / 2.)
-        text_r = r * .8
-        self.svg.node(serie_node['overlay'], 'text',
-                      x=center[0] + text_r * cos(text_angle),
-                      y=center[1] - text_r * sin(text_angle),
-                      id="reactive-%s" % tag,
-                      class_='reactive-text'
-              ).text = '{:.2%}'.format(perc)
+                          d='M%s A%s 0 %d 1 %s L%s A%s 0 %d 0 %s z' % (
+                              to1,
+                              get_radius(r), int(angle > pi), to2,
+                              to3,
+                              get_radius(small_r), int(angle > pi), to4),
+                          class_='slice reactive tooltip-trigger')
+        self.svg.node(slice_, 'desc', class_="value").text = val
+        tooltip_position = map(
+            str, diff(center, project(
+                (r + small_r) / 2., start_angle + angle / 2.)))
+        self.svg.node(slice_, 'desc',
+                      class_="x centered").text = tooltip_position[0]
+        self.svg.node(slice_, 'desc',
+                      class_="y centered").text = tooltip_position[1]
+        if self.print_values:
+            self.svg.node(
+                serie_node['text_overlay'], 'text',
+                class_='centered',
+                x=tooltip_position[0],
+                y=tooltip_position[1]
+            ).text = val if self.print_zeroes or val != '0%' else ''
 
     def _compute(self):
         for serie in self.series:
@@ -78,8 +93,7 @@ class Pie(Graph):
             self.slice(
                 self._serie(serie.index),
                 current_angle,
-                angle, sum(serie.values) / total,
-                '%d' % serie.index)
+                angle, sum(serie.values) / total)
             if len(serie.values) > 1:
                 small_current_angle = current_angle
                 for i, val in enumerate(serie.values):
@@ -88,7 +102,6 @@ class Pie(Graph):
                         self._serie(serie.index),
                         small_current_angle,
                         small_angle, val / total,
-                        '%d_%d' % (serie.index, i),
                         True)
                     small_current_angle += small_angle
             current_angle += angle
